@@ -760,96 +760,3 @@ gpk_task_new (void)
 	task = g_object_new (GPK_TYPE_TASK, NULL);
 	return GPK_TASK (task);
 }
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-static void
-gpk_task_test_install_packages_cb (GObject *object, GAsyncResult *res, EggTest *test)
-{
-	GpkTask *task = GPK_TASK (object);
-	GError *error = NULL;
-	PkResults *results;
-	GPtrArray *packages;
-	PkError *error_code = NULL;
-
-	/* get the results */
-	results = pk_task_generic_finish (PK_TASK(task), res, &error);
-	if (results == NULL) {
-		egg_test_failed (test, "failed to resolve: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* check error code */
-	error_code = pk_results_get_error_code (results);
-	if (error_code != NULL)
-		egg_test_failed (test, "failed to resolve success: %s", pk_error_get_details (error_code));
-
-	packages = pk_results_get_package_array (results);
-	if (packages == NULL)
-		egg_test_failed (test, "no packages!");
-
-	if (packages->len != 4)
-		egg_test_failed (test, "invalid number of packages: %i", packages->len);
-
-	g_ptr_array_unref (packages);
-out:
-	if (error_code != NULL)
-		g_object_unref (error_code);
-	if (results != NULL)
-		g_object_unref (results);
-	egg_test_loop_quit (test);
-}
-
-static void
-gpk_task_test_progress_cb (PkProgress *progress, PkProgressType type, EggTest *test)
-{
-	PkStatusEnum status;
-	if (type == PK_PROGRESS_TYPE_STATUS) {
-		g_object_get (progress,
-			      "status", &status,
-			      NULL);
-		g_debug ("now %s", pk_status_enum_to_string (status));
-	}
-}
-
-void
-gpk_task_test (gpointer user_data)
-{
-	EggTest *test = (EggTest *) user_data;
-	GpkTask *task;
-	gchar **package_ids;
-
-	if (!egg_test_start (test, "GpkTask"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get task");
-	task = gpk_task_new ();
-	egg_test_assert (test, task != NULL);
-
-	/* For testing, you will need to manually do:
-	pkcon repo-set-data dummy use-gpg 1
-	pkcon repo-set-data dummy use-eula 1
-	pkcon repo-set-data dummy use-media 1
-	*/
-
-	/************************************************************/
-	egg_test_title (test, "install package");
-	package_ids = pk_package_ids_from_id ("vips-doc;7.12.4-2.fc8;noarch;linva");
-	pk_task_install_packages_async (PK_TASK(task), package_ids, NULL,
-				        (PkProgressCallback) gpk_task_test_progress_cb, test,
-				        (GAsyncReadyCallback) gpk_task_test_install_packages_cb, test);
-	g_strfreev (package_ids);
-	egg_test_loop_wait (test, 150000);
-	egg_test_success (test, "installed in %i", egg_test_elapsed (test));
-
-	g_object_unref (task);
-	egg_test_end (test);
-}
-#endif
-
